@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: Apache-2.0
 from dataclasses import dataclass
 from typing import List
+from typing import Optional
 
 
 @dataclass(frozen=True)
@@ -18,8 +19,8 @@ class LineageTable:
         A string holding the table name
     """
 
-    catalog: str
-    schema: str
+    catalog: Optional[str]
+    schema: Optional[str]
     table: str
 
     def __str__(self):
@@ -59,4 +60,4 @@ class LineageData:
     query_type: str
     query_status: str
     input_tables: List[LineageTable]
-    output_table: LineageTable
+    output_table: Optional[LineageTable]
