@@ -1,11 +1,13 @@
-from vdk.internal.core.config import Configuration, ConfigurationBuilder
+# Copyright 2021 VMware, Inc.
+# SPDX-License-Identifier: Apache-2.0
+from vdk.internal.core.config import Configuration
+from vdk.internal.core.config import ConfigurationBuilder
 
 OPENLINEAGE_API_KEY = "OPENLINEAGE_API_KEY"
 OPENLINEAGE_URL = "OPENLINEAGE_URL"
 
 
 class OpenLineageConfiguration:
-
     def __init__(self, config: Configuration):
         self.__config = config
 
