@@ -2,13 +2,14 @@
 # SPDX-License-Identifier: Apache-2.0
 import logging
 import uuid
-from contextlib import contextmanager
+from abc import abstractmethod
 from typing import List
 from typing import Optional
 
 import pluggy
 from openlineage.client import OpenLineageClient
 from openlineage.client.facet import ParentRunFacet
+from openlineage.client.run import RunEvent
 from openlineage.client.run import RunState
 from vdk.api.plugin.hook_markers import hookimpl
 from vdk.internal.builtin_plugins.config.job_config import JobConfigKeys
@@ -19,6 +20,7 @@ from vdk.internal.builtin_plugins.run.job_context import JobContext
 from vdk.internal.core.config import ConfigurationBuilder
 from vdk.internal.core.context import CoreContext
 from vdk.internal.core.statestore import CommonStoreKeys
+from vdk.internal.core.statestore import StoreKey
 from vdk.internal.plugin.plugin import PluginRegistry
 from vdk.plugin.lineage import openlineage_config
 from vdk.plugin.lineage.openlineage_config import OpenLineageConfiguration
@@ -30,6 +32,15 @@ from vdk.plugin.lineage.openlineage_utils import VdkJobFacet
 log = logging.getLogger(__name__)
 
 
+class IOpenLineageClient:
+    @abstractmethod
+    def emit(self, event: RunEvent):
+        pass
+
+
+OPENLINEAGE_LOGGER_KEY = StoreKey[IOpenLineageClient]("open-lineage-logger")
+
+
 class OpenLineagePlugin:
     def __init__(self):
         self.__client: Optional[OpenLineageClient] = None
@@ -54,6 +65,11 @@ class OpenLineagePlugin:
         if config.url():
             log.debug(f"Open lineage client is enabled at url: {config.url()}")
             self.__client = setup_client(config.url(), config.api_key())
+        elif context.state.get(OPENLINEAGE_LOGGER_KEY) is not None:
+            self.__client = context.state.get(OPENLINEAGE_LOGGER_KEY)
+            log.debug(
+                f"Open lineage client custom implementation set. Type: {type(self.__client)} "
+            )
         else:
             log.debug(
                 "No OpenLineage url set. Collecting openlineage data is disabled."
@@ -140,28 +156,9 @@ class OpenLineagePlugin:
             )
 
 
-@contextmanager
-def no_op_dict_config():
-    import logging.config
-
-    cached_dict_config = logging.config.dictConfig
-    logging.config.dictConfig = lambda x: None
-    try:
-        yield
-    finally:
-        logging.config.dictConfig = cached_dict_config
-
-
 @hookimpl
 def vdk_start(plugin_registry: PluginRegistry, command_line_args: List) -> None:
     """
     Load all lineage vdk plugins
     """
-
-    with no_op_dict_config():
-        from sqllineage.core.models import Table
-        from sqllineage.runner import LineageRunner
-
-    l = LineageRunner("")
-
     plugin_registry.load_plugin_with_hooks_impl(OpenLineagePlugin())
